package com.akamai.ampdemo;

import android.app.Activity;
import android.content.DialogInterface;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.WindowManager;
import android.widget.ProgressBar;

import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;

public class MainActivity extends Activity implements DialogInterface.OnCancelListener, IPlayerEventsListener {

    private final static String TAG = "AMPv6";
    private final static String LICENSE = "vcgcJ_EWfa08ixnfP3_tdfKfhUwXd1j10Rb8jsM81xZOUEKW3o1HMC6vC0hSv5lod8ebk_evgilQRYBzb_zFKg==";
    private final static String VIDEO_URL = "http://multiplatform-f.akamaihd.net/i/multi/will/bunny/big_buck_bunny_,640x360_400,640x360_700,640x360_1000,950x540_1500,1280x720_2000,1280x720_3000,.f4v.csmil/master.m3u8";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private ProgressBar mProgressBar;

    private Boolean mWasPlaying = false;
    private boolean mFullScreenMode;
    private int mCurrentPosition = 0;
    private MediaResource resource;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        if (savedInstanceState != null) {
            mFullScreenMode = savedInstanceState.getBoolean("FULLSCREEN");
            mCurrentPosition = savedInstanceState.getInt("CURRENT_POSITION");
        } else {
            mFullScreenMode = false;
            mCurrentPosition = 0;
        }

        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
                Log.i(TAG, "onVideoPlayerCreated()");
            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                resource = mediaResource;

                //mVideoContainer.setDefaultMode(VideoPlayerContainer.MODE_EXO);

                mVideoView = mVideoContainer.getVideoPlayer();
                mVideoView.setProgressBarControl(mProgressBar);
                mVideoView.setLicense(LICENSE);
                mVideoView.setFullScreen(true);
                mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
                mVideoView.setLogEnabled(true);

                //addMediaAnalytics();

                mVideoView.play(resource, mCurrentPosition);
            }

            @Override
            public void onResourceError() {
                Log.e(TAG, "onResourceError()");
            }
        });

        mVideoContainer.prepareResource(VIDEO_URL);
    }

    //SOLA Analytics implementation in AMP:
    private void addMediaAnalytics() {
        //Set the Configuration URL to the SDK
        //mVideoView.setMediaAnalyticsConfigUrl(MEDIA_ANALYTICS_CONFIG_URL);

        //In case custom event are needed.
        //mVideoView.setMediaAnalyticsData("eventName", "Custom event");
    }


    @Override
    protected void onResume() {
        Log.d(TAG, "OnResume");
        if (mWasPlaying) {
            mVideoView.play(resource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d(TAG, "OnPause");
        if ((mVideoView != null) && (mVideoView.isPlaying() || mVideoView.isPaused())) {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
            mVideoView.stop();
        }

        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d(TAG, "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {

        return true;
    }

    @Override
    public void onCancel(DialogInterface dialog)
    {
        finish();
    }

    @Override
    public void onSaveInstanceState(Bundle savedInstanceState) {
        savedInstanceState.putBoolean("FULLSCREEN", mFullScreenMode);
        savedInstanceState.putInt("CURRENT_POSITION", mCurrentPosition);
        // Always call the superclass so it can save the view hierarchy state
        super.onSaveInstanceState(savedInstanceState);
    }

}
