package com.akamai.ampfreewheelsample;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.WindowManager;

import com.akamai.androidsdk_freewheel_module.FWAdComponent;
import com.akamai.androidsdk_freewheel_module.IFWAdComponentListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerContainer.VideoPlayerContainerCallback;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;
import com.akamai.ui.listeners.IMediaPlayerControllerListener;
import com.akamai.ui.media.MediaPlayerController;

public class FreeWheelActivity extends AppCompatActivity implements VideoPlayerContainerCallback,IFWAdComponentListener,IMediaPlayerControllerListener {

    public static final String TAG = FreeWheelActivity.class.getName();
    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private MediaResource mediaResource;
    private FWAdComponent fwAdComponent;
    private MediaPlayerController mediaPlayerController;

    private int currentPosition = 0;
    private boolean wasPlaying = false;
    private boolean isAdPlaying = false;

    private int fwNetworkId = 42015;
    private String fwAdsURL = "http://demo.v.fwmrm.net/";
    private String fwProfile = "fw_tutorial_android";
    private String fwSiteSectionId = "fw_tutorial_android";
    private String fwVideoAssetId = "fw_simple_tutorial_asset";



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        Log.e(TAG,"onCreate");
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        mediaPlayerController = (MediaPlayerController) findViewById(R.id.controller);
        mediaPlayerController.hideFullscreenButton();
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.videoContainer);
        mVideoContainer.addVideoPlayerContainerCallback(this);
        mVideoContainer.prepareResource(getString(R.string.m3u8));

        fwAdComponent = new FWAdComponent(this,fwNetworkId,fwAdsURL,fwSiteSectionId,fwVideoAssetId,fwProfile);
        fwAdComponent.addEventListener(this);
        fwAdComponent.setVideoContainer(mVideoContainer);
    }

    @Override
    public void onBackPressed() {
        this.moveTaskToBack(true);
    }

    private void configVideoPlayer(){
        mediaPlayerController.setVideoPlayerView(mVideoContainer);
        mediaPlayerController.setEventsListener(this);

        mVideoView = mVideoContainer.getVideoPlayer();
        mVideoView.setLicense(getString(R.string.license_key));
        mVideoView.setLogEnabled(true);

        fwAdComponent.setVideoPlayerView(mVideoView);
    }

    @Override
    public void onVideoPlayerCreated() {
        Log.e(TAG,"onVideoPlayerCreated");
    }

    @Override
    public void onResourceReady(MediaResource resource) {
        Log.e(TAG,"onResourceReady");
        mediaResource = resource;
        this.configVideoPlayer();
        mVideoView.play(mediaResource);
    }

    @Override
    public void onResourceError() {
        Log.e(TAG,"onResourceError");
    }

    @Override
    protected void onResume(){
        Log.e(TAG, "onResume");
        fwAdComponent.onResume();
        if(mVideoView != null && !isAdPlaying){
            mVideoView.play(mediaResource,currentPosition);
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.e(TAG,"onPause");
        fwAdComponent.onPause();
        if(mVideoView != null && !isAdPlaying){
            currentPosition = mVideoView.getTimePosition();
            mVideoView.stop();
        }
        super.onPause();
    }

    @Override
    protected void onStop() {
        Log.e(TAG,"onStop");
        super.onStop();
        fwAdComponent.onStop();
    }

    @Override
    protected void onDestroy() {
        Log.e(TAG,"onDestroy");
        super.onDestroy();
        mVideoView.onDestroy();
        fwAdComponent.onDestroy();
    }

    @Override
    protected void onStart() {
        Log.e(TAG,"onStart");
        super.onStart();
        fwAdComponent.onStart();
    }

    @Override
    protected void onRestart() {
        Log.e(TAG,"onRestart");
        super.onRestart();
        fwAdComponent.onRestart();
    }

    //IFWAdComponentListener

    @Override
    public void onAdsEnded() {
        Log.e(TAG,"onAdsEnded");
        mediaPlayerController.showControlBar(true);
        isAdPlaying = false;
    }

    @Override
    public void onAdsStarted() {
        Log.e(TAG,"onAdsStarted");
        mediaPlayerController.showControlBar(false);
        isAdPlaying = true;
    }

    @Override
    public void onAdsPaused() {
        Log.e(TAG,"onAdsPaused");
    }

    @Override
    public void onAdsResumed() {
        Log.e(TAG,"onAdsResumed");
    }

    @Override
    public void onButtonClicked(int buttonId) {

    }
}
