package com.akamai.androidmdt.androidsdkdemo;


import android.app.FragmentTransaction;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.support.v4.app.FragmentActivity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ProgressBar;

import com.akamai.ads.AdsComponent;
import com.akamai.ads.IAdsComponentListener;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;


public class PlayerActivity extends FragmentActivity implements IPlayerEventsListener, IAdsComponentListener {

    private final int COMMAND_PLAYING = 1;
    private final int COMMAND_START_BUFFERING = 3;
    private final int COMMAND_END_BUFFERING = 4;
    private final int COMMAND_UPDATE_POSITION = 5;
    private int lastPosition = 0;


    private final String MEDIA_ASSET_URL = "http://mediapm.edgesuite.net/ovp/content/demo/video/elephants_dream/elephants_dream_768x428_24.0fps_608kbps.mp4";
    private MediaResource mediaResource;
    private String adsURL = "http://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpost&cmsid=496&vid=short_onecue&correlator=";
    private String licenseKey = "jhq53pcM9osz0gYJBzf9MKbiOBf0Cv82k1qj3keKGiSRqPxnTEE-3-gDMqiFJPY80X1yU2WzHxXlA0CZv9N2lw==";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private ProgressBar progressBar;
    private PlayerSeekControls playerSeekControls;
    private AdsComponent adsComponent;

    private Boolean mWasPlaying = false;
    private int mCurrentPosition = 0;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_player);
        playerSeekControls = (PlayerSeekControls) getFragmentManager().findFragmentById(R.id.playerSeekbar);
        playerSeekControls.setParent(this);
        progressBar = (ProgressBar) findViewById(R.id.progressBar);
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.view);
        configurePlayer();

        FragmentTransaction ftr = getFragmentManager().beginTransaction();
        ftr.hide(playerSeekControls);
        ftr.commit();
    }

    public void configurePlayer(){

        // Play the video
        mVideoContainer.prepareResource(MEDIA_ASSET_URL);

        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
            }

            @Override
            public void onResourceReady(MediaResource resource) {

                mediaResource = resource;
                onMediaResourceReady();
            }

            @Override
            public void onResourceError() {
            }
        });
    }

    private void onMediaResourceReady() {

        configVideoView();
        configAdsComponent();
        mVideoView.play(mediaResource);
    }

    private void configVideoView() {
        mVideoView = mVideoContainer.getVideoPlayer();
        mVideoView.addEventsListener(PlayerActivity.this);
        mVideoView.setLicense(licenseKey);
        mVideoView.setKeepScreenOn(true);
        mVideoView.setProgressBarControl(progressBar);
    }

    private void configAdsComponent() {
        adsComponent = new AdsComponent(PlayerActivity.this);
        adsComponent.attachToVideoPlayerContainer(mVideoContainer);
        adsComponent.setAdsUrl(adsURL);
        adsComponent.setEventsListener(PlayerActivity.this);
        adsComponent.setVideoPlayerView(mVideoView);
    }

    @Override
    public void onResume(){
        if(adsComponent != null && !adsComponent.isAdPlaying() && adsComponent.isAdStarted())
               adsComponent.resumeAd();

        if (mVideoView != null && mWasPlaying) {
            mVideoView.play(mediaResource, mCurrentPosition);
            mWasPlaying = false;
        }

        super.onResume();
    }

    @Override
    public void onPause(){
        if(adsComponent != null && adsComponent.isAdPlaying() && adsComponent.isAdStarted())
           adsComponent.pauseAd();

        if (mVideoView != null && (mVideoView.isPlaying() || mVideoView.isPaused()) && !adsComponent.isAdStarted())
        {
            mCurrentPosition = mVideoView.getTimePosition();
            mWasPlaying = true;
            mVideoView.stop();
        }

        super.onPause();
    }

    //code for seek to the position
    public void seek(int position){
        mVideoView.seek(position);
    }


    //code for handle different command messages
    public Handler commandHandler = new Handler(){
        @Override
        public void handleMessage(Message msg) {
           switch (msg.what){
               case COMMAND_PLAYING:

                   playerSeekControls.setDuration(mVideoView.getDuration());
                   break;
               case COMMAND_END_BUFFERING :
                   break;
               case COMMAND_START_BUFFERING :
                   break;
               case COMMAND_UPDATE_POSITION :
                        updatePosition();
                        lastPosition = mVideoView.getTimePosition();
                   break;
           }

            super.handleMessage(msg);
        }
    };


    //code for update video progress based on position received
    public void updatePosition(){
       playerSeekControls.setProgress(mVideoView.getTimePosition());
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_player, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {

            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int eventType) {
        switch (eventType){
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_PLAYING:
                commandHandler.sendEmptyMessage(COMMAND_PLAYING);
                //akaPlugin.handlePlay();
                break;
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_START_REBUFFERING:
                 commandHandler.sendEmptyMessage(COMMAND_START_BUFFERING);
                //akaPlugin.handleBufferStart();
                break;
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_END_REBUFFERING:
                commandHandler.sendEmptyMessage(COMMAND_END_BUFFERING);
                //akaPlugin.handleBufferEnd();
                break;
            case IPlayerEventsListener.PLAYER_EVENT_TYPE_POSITION_UPDATE:
                commandHandler.sendEmptyMessage(COMMAND_UPDATE_POSITION);
                break;
        }
        return true;
    }


    @Override
    public boolean onPlayerExtendedEvent(int i, int i2, int i3) {
        return true;
    }


    //code for add event listener function
    @Override
    public void onAdsError(String s) {

    }

    @Override
    public void onPauseContentRequested() {
        FragmentTransaction ftr = getFragmentManager().beginTransaction();
        ftr.hide(playerSeekControls);
        ftr.commit();
    }

    @Override
    public void onResumeContentRequested() {
        FragmentTransaction ftr = getFragmentManager().beginTransaction();
        ftr.show(playerSeekControls);
        ftr.commit();
    }

    @Override
    public void onAdsLoaded() {

    }

    @Override
    public void onAdsStarted() {

    }

    @Override
    public void onAdsPaused() {

    }

    @Override
    public void onAdsResumed() {

    }

    @Override
    public void onAdsTrackProgress(int i) {

      /*if(i==3){
           adsComponent.setAdsEnabled(false);
           FragmentTransaction ftr = getFragmentManager().beginTransaction();
           ftr.show(playerSeekControls);
           ftr.commit();
      }*/
    }
}
