package com.akamai.ampdemoui;

import android.app.Activity;
import android.content.pm.ActivityInfo;
import android.content.res.Configuration;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ImageButton;
import android.widget.ProgressBar;

import com.akamai.media.AMPLibraryInfo;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.MediaResource;
import com.akamai.ui.listeners.IMediaPlayerControllerListener;
import com.akamai.ui.media.MediaPlayerController;


public class MainActivity extends Activity implements IMediaPlayerControllerListener {

    private final String TAG = MainActivity.class.getSimpleName();

    // Video Player container object
    private VideoPlayerContainer mVideoPlayerContainer;

    // Video Player object
    private VideoPlayerView mVideoPlayerView;

    // Control bar component
    private MediaPlayerController mMediaPlayerController;

    private MediaResource resource;

    // Progress bar control
    private ProgressBar mProgressBar;

    // Android SDK License
    private static final String ANDROID_SDK_LICENSE = "eSwrM-aDq2lv2d35NMXiigENPdd1RFUKfL7LJbTfOfjP_MleTGEZLEJYXIqNVJ8dVN4R1eoj-VZ22Up0XCK_Wg==";

    // Media Asset url
    private static final String MEDIA_ASSET_URL = "http://sblancovodmdev-f.akamaihd.net/i/temp/bbb.mp4/master.m3u8";

    // Keep current fullscreen mode
    private boolean mFullScreenMode, mWasPlaying;

    private int mCurrentPosition;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        validateFullScreenState();
        setContentView(R.layout.activity_main);

        if (savedInstanceState != null) {
            mFullScreenMode = savedInstanceState.getBoolean("FULLSCREEN");
            mCurrentPosition = savedInstanceState.getInt("CURRENT_POSITION");
        } else {
            mFullScreenMode = false;
            mCurrentPosition = 0;
        }

        // Initialize Progress Bar
        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);
        // Initialize and configure the VideoPlayerContainer and VideoPlayerView
        mVideoPlayerContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);
        mVideoPlayerContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {

            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                resource = mediaResource;
                mVideoPlayerView = mVideoPlayerContainer.getVideoPlayer();

                mVideoPlayerView.setLicense(ANDROID_SDK_LICENSE);
                mVideoPlayerView.setLogEnabled(true);

                // Initialize UI Control bar
                mMediaPlayerController = (MediaPlayerController) findViewById(R.id.playerControls);

                setFullScreenState(mFullScreenMode);
                // Set the VideoPlayer object to the MediaController
                mMediaPlayerController.setVideoPlayerView(mVideoPlayerContainer);

                // Set this object to listen SDK events and start playing the url
                mVideoPlayerView.setProgressBarControl(mProgressBar);

                // Listen to control bar events
                mMediaPlayerController.setEventsListener(MainActivity.this);

                // Play Url
                mVideoPlayerView.play(mediaResource, mCurrentPosition);

                Log.i(TAG, "VERSION: "+ AMPLibraryInfo.VERSION);

            }

            @Override
            public void onResourceError() {

            }
        });

        mVideoPlayerContainer.prepareResource(MEDIA_ASSET_URL);
    }

    private void validateFullScreenState() {
        if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_LANDSCAPE)
        {

            requestWindowFeature(Window.FEATURE_NO_TITLE);
            this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);
        }
        else if (getResources().getConfiguration().orientation == Configuration.ORIENTATION_PORTRAIT)
        {
            requestWindowFeature(Window.FEATURE_ACTION_BAR);
            this.getWindow().setFlags(WindowManager.LayoutParams.FLAG_FORCE_NOT_FULLSCREEN, WindowManager.LayoutParams.FLAG_FORCE_NOT_FULLSCREEN);
        }
    }


    @Override
    protected void onResume() {
        if (mVideoPlayerView != null && mWasPlaying)
            mVideoPlayerView.play(resource, mCurrentPosition);

        Log.e(TAG, "onResume");
        super.onResume();
    }


    @Override
    protected void onPause() {
        Log.e(TAG, "onPause");
        if(mVideoPlayerView != null && mVideoPlayerView.isPlaying()){
            mCurrentPosition = mVideoPlayerView.getTimePosition();
            mVideoPlayerView.stop();
            mWasPlaying = true;
        }
        super.onPause();
    }


    @Override
    protected void onDestroy() {
        if (mVideoPlayerView != null) {
            mVideoPlayerView.onDestroy();
        }
        super.onDestroy();
    }

    @Override
    public void onSaveInstanceState(Bundle savedInstanceState) {
        savedInstanceState.putBoolean("FULLSCREEN", mFullScreenMode);
        savedInstanceState.putInt("CURRENT_POSITION", mCurrentPosition);
        // Always call the superclass so it can save the view hierarchy state
        super.onSaveInstanceState(savedInstanceState);
    }

    private void setFullScreenMode(boolean fullscreen)
    {
        if(fullscreen == mFullScreenMode)
            return;
        mFullScreenMode = fullscreen;
        // Checks the orientation of the screen
        if (fullscreen) {
            mVideoPlayerView.setFullScreen(true);
            mVideoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);

            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);

        } else {
            mVideoPlayerView.setFullScreen(false);
            mVideoPlayerView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_NONE);

            setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        }
        setFullScreenState(mFullScreenMode);
    }

    private void setFullScreenState(boolean fullscreen){
        if (fullscreen) {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_FULLSCREEN);
        } else {
            mMediaPlayerController.setCurrentFullScreenMode(MediaPlayerController.UI_MODE_NON_FULLSCREEN);
        }
    }

    @Override
    public void onButtonClicked(int arg0) {

        if(arg0 == IMediaPlayerControllerListener.MEDIAPLAYERCONTROLLER_BUTTON_FULLSCREEN)
            setFullScreenMode(!mFullScreenMode);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        return false;
    }
}
